@@ -18,16 +18,25 @@
  */
 
 #define AMAP_PROGRAM   "amap"
-#define AMAP_VERSION   "v4.2"
+#define AMAP_VERSION   "v4.3"
 #define AMAP_YEAR      "2003"
 #define AMAP_AUTHOR    "van Hauser and DJ RevMoon"
 #define AMAP_EMAIL     "amap-dev@thc.org"
 #define AMAP_RESOURCE  "www.thc.org"
 
-#define AMAP_APPDEF_PATH	"/usr/local/bin"
+#ifndef AMAP_PREFIX
+ #ifdef PREFIX
+  #warning "PREFIX definition found, installing to this prefix directory location"
+  #define AMAP_PREFIX         PREFIX
+ #else
+  #define AMAP_PREFIX         "/usr/local"
+ #endif
+#endif
+
+#define AMAP_APPDEF_PATH	AMAP_PREFIX"/bin"
 #define AMAP_BUFSIZE		1024	// standard buffer size
 #define AMAP_BUFSIZE_BIG	65536   // big standard buffer size
-#define AMAP_REGEX_OPTIONS	( PCRE_MULTILINE | PCRE_CASELESS )
+#define AMAP_REGEX_OPTIONS	( PCRE_MULTILINE | PCRE_CASELESS | PCRE_DOTALL )
 
 /* connection and task definitions */
 #define AMAP_MAX_CONNECT_RETRIES	3	// connect() retries
